@@ -1097,8 +1097,8 @@ elsif ($sshmode == 2) {
 		}
 	}
 
+&run_post_actions();
 &virtualmin_api_log(\@OLDARGV, \%dom, $dom{'hashpass'} ? [ "pass" ] : [ ]);
-&run_post_actions_silently();
 &unlock_domain_name($domain);
 print "All done!\n";
 
