@@ -698,6 +698,14 @@ if ($multiline) {
 				}
 			}
 
+		# Show proxy hostname setting
+		if (&has_proxy_host($d)) {
+			my $ph = &get_domain_proxy_host($d);
+			print "    Proxy hostname: ",
+				($ph == 0 ? "No" :
+				 $ph == 1 ? "Yes" : "Unsupported"),"\n";
+			}
+
 		# Show SSL cert
 		if ($d->{'ssl_key'}) {
 			print "    SSL key file: $d->{'ssl_key'}\n";
@@ -732,10 +740,12 @@ if ($multiline) {
 			print "    SSL provider renewal: ",
 			    ($d->{'letsencrypt_renew'} ? "Enabled"
 						       : "Disabled"),"\n";
-			print "    SSL provider email: ",
+			print "    SSL provider renewal email: ",
 			    ($d->{'letsencrypt_email'} == 0 ? "Always" :
 			     $d->{'letsencrypt_email'} == 1 ? "On error" :
 							      "Never"),"\n";
+			print "    SSL provider renewal email master: ",
+			 ($d->{'letsencrypt_email_master'} ? "Yes" : "No"),"\n";
 			}
 		if ($d->{'letsencrypt_last'}) {
 			print "    SSL provider cert issued: ",
